package com.ruoyi.record.controller;

import java.io.File;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.config.RuoYiConfig;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.record.domain.RecordBusbarTemp;
import com.ruoyi.record.service.IRecordBusbarTempService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 母排测温信息Controller
 * 
 * @author zangch
 * @date 2024-11-07
 */
@RestController
@RequestMapping("/record/recordBusbarTemp")
public class RecordBusbarTempController extends BaseController
{
    @Autowired
    private IRecordBusbarTempService recordBusbarTempService;

    /**
     * 查询母排测温信息列表
     */
    @PreAuthorize("@ss.hasPermi('record:recordBusbarTemp:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecordBusbarTemp recordBusbarTemp)
    {
        startPage();
        List<RecordBusbarTemp> list = recordBusbarTempService.selectRecordBusbarTempList(recordBusbarTemp);
        return getDataTable(list);
    }

    /**
     * 导出母排测温信息列表
     */
    @PreAuthorize("@ss.hasPermi('record:recordBusbarTemp:export')")
    @Log(title = "母排测温信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecordBusbarTemp recordBusbarTemp)
    {
        List<RecordBusbarTemp> list = recordBusbarTempService.selectRecordBusbarTempList(recordBusbarTemp);
        ExcelUtil<RecordBusbarTemp> util = new ExcelUtil<RecordBusbarTemp>(RecordBusbarTemp.class);
        util.exportExcel(response, list, "母排测温信息数据");
    }

    /**
     * 获取母排测温信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('record:recordBusbarTemp:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId)
    {
        return success(recordBusbarTempService.selectRecordBusbarTempByObjId(objId));
    }

    /**
     * 新增母排测温信息
     */
    @PreAuthorize("@ss.hasPermi('record:recordBusbarTemp:add')")
    @Log(title = "母排测温信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordBusbarTemp recordBusbarTemp)
    {
        return toAjax(recordBusbarTempService.insertRecordBusbarTemp(recordBusbarTemp));
    }

    /**
     * 修改母排测温信息
     */
    @PreAuthorize("@ss.hasPermi('record:recordBusbarTemp:edit')")
    @Log(title = "母排测温信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordBusbarTemp recordBusbarTemp)
    {
        return toAjax(recordBusbarTempService.updateRecordBusbarTemp(recordBusbarTemp));
    }

    /**
     * 删除母排测温信息
     */
    @PreAuthorize("@ss.hasPermi('record:recordBusbarTemp:remove')")
    @Log(title = "母排测温信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds)
    {
        return toAjax(recordBusbarTempService.deleteRecordBusbarTempByObjIds(objIds));
    }


    /**
     * 获取可见光照片。
     * @param filePath 需要获取的可见光照片的文件路径。
     * @return 如果文件存在，返回包含文件资源的ResponseEntity对象；如果文件不存在，返回null。
     */
    @GetMapping("/getVisiblePhoto/{filePath}")
    public ResponseEntity<FileSystemResource> getVisiblePhoto(@PathVariable String filePath) {
        // 获取配置文件中的路径application.yml的profile
        String myPath = RuoYiConfig.getProfile();
        // 构建文件的完整路径
        String fileUrl = myPath + "/日志信息/红外热成像/" + filePath;
        // 创建文件对象
        File file = new File(fileUrl);
        // 检查文件是否存在
        if (file.exists()) {
            // 将文件包装成FileSystemResource对象
            FileSystemResource resource = new FileSystemResource(file);
            // 创建HttpHeaders对象，用于设置响应头
            HttpHeaders headers = new HttpHeaders();
            // 设置媒体类型为图片jpg格式
            headers.setContentType(MediaType.parseMediaType("image/jpg"));
            headers.setContentLength(file.length());
            // 返回包含文件资源的ResponseEntity对象
            return ResponseEntity.ok()
                    .headers(headers)
                    .body(resource);
        } else {
            // 如果文件不存在，返回null（注释掉的代码是返回404状态）
            /* return ResponseEntity.notFound().build(); */
            return null;
        }
    }

    /**
     * 获取热成像照片。
     * @param filePath 需要获取的热成像照片的文件路径。
     * @return 如果文件存在，返回包含文件资源的响应实体；如果文件不存在，返回null（注释掉的代码是返回404状态）。
     */
    @GetMapping("/getThermalPhoto/{filePath}")
    public ResponseEntity<FileSystemResource> getThermalPhoto(@PathVariable String filePath) {
        // 获取配置文件中的路径application.yml的profile
        String myPath = RuoYiConfig.getProfile();
        // 构建完整的文件路径
        String fileUrl = myPath + "/日志信息/可见光图像/" + filePath;
        // 创建文件对象
        File file = new File(fileUrl);
        // 检查文件是否存在
        if (file.exists()) {
            // 创建文件系统资源对象
            FileSystemResource resource = new FileSystemResource(file);
            // 创建HTTP头对象
            HttpHeaders headers = new HttpHeaders();
            // 设置媒体类型为图片jpg格式
            headers.setContentType(MediaType.parseMediaType("image/jpg"));
            headers.setContentLength(file.length());
            // 返回包含文件资源的响应实体
            return ResponseEntity.ok()
                    .headers(headers)
                    .body(resource);
        } else {
            // 如果文件不存在，返回null（注释掉的代码是返回404状态）
            /* return ResponseEntity.notFound().build(); */
            return null;
        }
    }


}
